==> driza-0.6.0.tar.gz: driza-0.6/Driza/operaciones/ks.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#jicuadrado.py Operación jicuadrado

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from rpy import *

nombre="KS"
tipo="Calculo"

def funcion(dato,variable,caso,opciones):
	lista=[float(x) for x in dato.getCol(variable,caso=caso)]
	num=len(lista)
	if opciones[u"Distribución"]=="Uniforme":
		distribucion=r.runif(num,1./num,1./num)
	resultado=r.ks_test(lista,distribucion)
	resultado["Percentil"]=opciones["Percentil"] # Pasa al resultado sin procesar
	return resultado

def initresultado(resultado,opciones):
	resultado.addTablaSimple("resultado")
	resultado["resultado"].titulo="KS"
	lista=[]
	if opciones["caso"]:
		lista.append("Caso")
	lista+=["Percentil limite","percentil obtenido",u"Conclusión"]
	resultado["resultado"].settitulo(lista)

def interfazresultado(resultado,listaopciones):
	variable=listaopciones[0]
	caso=listaopciones[1]
	diccionario=listaopciones[2]
	lista=[]
	if caso:
		lista.append(caso)
	lista.append(diccionario["Percentil"])
	lista.append(diccionario["p.value"])
	if diccionario["p.value"]*100>diccionario["Percentil"]:
		lista.append("Se ajusta a la distribucion")
	else:
		lista.append("No se ajusta a la distribucion")
	resultado["resultado"].set(variable,lista)

widget={"tipo":"BondadDeAjuste"}


#blblbl

==> driza-0.6.1.tar.gz: driza-0.6.1/Driza/operaciones/ks.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#jicuadrado.py Operación jicuadrado

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from rpy import *

nombre="KS"
tipo="Calculo"

def funcion(dato,variable,caso,opciones):
	lista=dato.query(variable,caso)
	num=len(lista)
	numcasos=len(list(r.table(lista)))
	total=0

	if numcasos<30: #Cambiar por numero de casos
		if opciones[u"Distribución"]=="Uniforme":
			resultado=r.ks_test(list(r.table(lista)),r.runif)
	else:
		rango=r.range(lista)
		limiteinferior=rango[0]-0 #Averiguar la precision del float de python
		limitesuperior=rango[1]+0
		longitudrango=limitesuperior-limiteinferior
		numdivisiones=int(0.15*num)
		divisor=longitudrango/numdivisiones
		listaobtenida=[0 for x in range(numdivisiones)]
		for reg in lista:
			posicion=int(float(reg-limiteinferior-1)/divisor)
			if posicion>=numdivisiones: posicion=numdivisiones-1
			listaobtenida[posicion]+=1
		#Crear una nueva list, sumando 1 a cada posicion en funcion de cada elemento de lista
		if opciones[u"Distribución"]=="Uniforme":
			resultado=r.ks_test(listaobtenida,r.runif)


	resultado["Percentil"]=opciones["Percentil"] # Pasa al resultado sin procesar
	return resultado

def initresultado(resultado,opciones):
	resultado.addTablaSimple("resultado")
	resultado["resultado"].titulo="KS"
	lista=[]
	if opciones["caso"]:
		lista.append("Caso")
	lista+=["Percentil limite","Significacion",u"Conclusión"]
	resultado["resultado"].settitulo(lista)

def interfazresultado(resultado,listaopciones):
	variable=listaopciones[0]
	caso=listaopciones[1]
	diccionario=listaopciones[2]
	lista=[]
	if caso:
		lista.append(caso)
	lista.append(diccionario["Percentil"])
	lista.append(diccionario["p.value"])
	if diccionario["p.value"]*100>diccionario["Percentil"]:
		lista.append("Se ajusta a la distribucion")
	else:
		lista.append("No se ajusta a la distribucion")
	resultado["resultado"].set(variable,lista)

widget={"tipo":"BondadDeAjuste"}


#blblbl
